@@ -6,26 +6,18 @@ import weakref
 import redis
 
 from . import _msgs as msgs
-from ._commands import (Int, CommandItem)
+from ._commands import (Int, Float)
 from ._helpers import (
     SimpleError, valid_response_type, SimpleString, NoResponse, casematch,
     compile_pattern, QUEUED)
-from ._zset import ZSet
 
 
 class BaseFakeSocket:
-    def __init__(self, server):
+    def __init__(self, server, *args, **kwargs):
+        super(BaseFakeSocket, self).__init__(*args, **kwargs)
         self._server = server
         self._db = server.dbs[0]
         self._db_num = 0
-        # When in a MULTI, set to a list of function calls
-        self._transaction = None
-        self._transaction_failed = False
-        # Set when executing the commands from EXEC
-        self._in_transaction = False
-        self._watch_notified = False
-        self._watches = set()
-        self._pubsub = 0  # Count of subscriptions
         self.responses = queue.Queue()
         # Prevents parser from processing commands. Not used in this module,
         # but set by aioredis module to prevent new commands being processed
@@ -53,7 +45,8 @@ class BaseFakeSocket:
     def shutdown(self, flags):
         self._parser.close()
 
-    def fileno(self):
+    @staticmethod
+    def fileno():
         # Our fake socket must return an integer from `FakeSocket.fileno()` since a real selector
         # will be created. The value does not matter since we replace the selector with our own
         # `FakeSelector` before it is ever used.
@@ -119,7 +112,7 @@ class BaseFakeSocket:
     def _run_command(self, func, sig, args, from_script):
         command_items = {}
         try:
-            ret = sig.apply(args, self._db)
+            ret = sig.apply(args, self._db, self.version)
             if len(ret) == 1:
                 result = ret[0]
             else:
@@ -227,7 +220,7 @@ class BaseFakeSocket:
                 now = time.time()
                 for db in self._server.dbs.values():
                     db.time = now
-                sig.check_arity(fields[1:])
+                sig.check_arity(fields[1:], self.version)
                 # TODO: make a signature attribute for transactions
                 if self._transaction is not None \
                         and func_name not in ('exec', 'discard', 'multi', 'watch'):
@@ -250,36 +243,6 @@ class BaseFakeSocket:
         if not isinstance(result, NoResponse):
             self.put_response(result)
 
-    def notify_watch(self):
-        self._watch_notified = True
-
-    # redis has inconsistent handling of negative indices, hence two versions
-    # of this code.
-
-    @staticmethod
-    def _fix_range_string(start, end, length):
-        # Negative number handling is based on the redis source code
-        if start < 0 and end < 0 and start > end:
-            return -1, -1
-        if start < 0:
-            start = max(0, start + length)
-        if end < 0:
-            end = max(0, end + length)
-        end = min(end, length - 1)
-        return start, end + 1
-
-    @staticmethod
-    def _fix_range(start, end, length):
-        # Redis handles negative slightly differently for zrange
-        if start < 0:
-            start = max(0, start + length)
-        if end < 0:
-            end += length
-        if start > end or start >= length:
-            return -1, -1
-        end = min(end, length - 1)
-        return start, end + 1
-
     def _scan(self, keys, cursor, *args):
         """
         This is the basis of most of the ``scan`` methods.
@@ -294,7 +257,7 @@ class BaseFakeSocket:
         """
         cursor = int(cursor)
         pattern = None
-        type = None
+        _type = None
         count = 10
         if len(args) % 2 != 0:
             raise SimpleError(msgs.SYNTAX_ERROR_MSG)
@@ -306,7 +269,7 @@ class BaseFakeSocket:
                 if count <= 0:
                     raise SimpleError(msgs.SYNTAX_ERROR_MSG)
             elif casematch(args[i], b'type'):
-                type = args[i + 1]
+                _type = args[i + 1]
             else:
                 raise SimpleError(msgs.SYNTAX_ERROR_MSG)
 
@@ -322,11 +285,11 @@ class BaseFakeSocket:
             return regex.match(key) if pattern is not None else True
 
         def match_type(key):
-            if type is not None:
-                return casematch(self._type(self._db[key]).value, type)
+            if _type is not None:
+                return casematch(self._type(self._db[key]).value, _type)
             return True
 
-        if pattern is not None or type is not None:
+        if pattern is not None or _type is not None:
             for val in itertools.islice(data, cursor, result_cursor):
                 compare_val = val[0] if isinstance(val, tuple) else val
                 if match_key(compare_val) and match_type(compare_val):
@@ -338,145 +301,20 @@ class BaseFakeSocket:
             result_cursor = 0
         return [str(result_cursor).encode(), result_data]
 
-    @staticmethod
-    def _calc_setop(op, stop_if_missing, key, *keys):
-        if stop_if_missing and not key.value:
-            return set()
-        value = key.value
-        if not isinstance(value, set):
-            raise SimpleError(msgs.WRONGTYPE_MSG)
-        ans = value.copy()
-        for other in keys:
-            value = other.value if other.value is not None else set()
-            if not isinstance(value, set):
-                raise SimpleError(msgs.WRONGTYPE_MSG)
-            if stop_if_missing and not value:
-                return set()
-            ans = op(ans, value)
-        return ans
-
-    def _setop(self, op, stop_if_missing, dst, key, *keys):
-        """Apply one of SINTER[STORE], SUNION[STORE], SDIFF[STORE].
-
-        If `stop_if_missing`, the output will be made an empty set as soon as
-        an empty input set is encountered (use for SINTER[STORE]). May assume
-        that `key` is a set (or empty), but `keys` could be anything.
-        """
-        ans = self._calc_setop(op, stop_if_missing, key, *keys)
-        if dst is None:
-            return list(ans)
+    def _ttl(self, key, scale):
+        if not key:
+            return -2
+        elif key.expireat is None:
+            return -1
         else:
-            dst.value = ans
-            return len(dst.value)
+            return int(round((key.expireat - self._db.time) * scale))
 
-    def _type(self, key):
-        if key.value is None:
-            return SimpleString(b'none')
-        elif isinstance(key.value, bytes):
-            return SimpleString(b'string')
-        elif isinstance(key.value, list):
-            return SimpleString(b'list')
-        elif isinstance(key.value, set):
-            return SimpleString(b'set')
-        elif isinstance(key.value, ZSet):
-            return SimpleString(b'zset')
-        elif isinstance(key.value, dict):
-            return SimpleString(b'hash')
-        else:
-            assert False  # pragma: nocover
+    def _encodefloat(self, value, humanfriendly):
+        if self.version >= 7:
+            value = 0 + value
+        return Float.encode(value, humanfriendly)
 
-    def _clear_watches(self):
-        self._watch_notified = False
-        while self._watches:
-            (key, db) = self._watches.pop()
-            db.remove_watch(key, self)
-
-    # Pubsub commands
-    # TODO: pubsub command
-
-    def _subscribe(self, channels, subscribers, mtype):
-        for channel in channels:
-            subs = subscribers[channel]
-            if self not in subs:
-                subs.add(self)
-                self._pubsub += 1
-            msg = [mtype, channel, self._pubsub]
-            self.put_response(msg)
-        return NoResponse()
-
-    def _unsubscribe(self, channels, subscribers, mtype):
-        if not channels:
-            channels = []
-            for (channel, subs) in subscribers.items():
-                if self in subs:
-                    channels.append(channel)
-        for channel in channels:
-            subs = subscribers.get(channel, set())
-            if self in subs:
-                subs.remove(self)
-                if not subs:
-                    del subscribers[channel]
-                self._pubsub -= 1
-            msg = [mtype, channel, self._pubsub]
-            self.put_response(msg)
-        return NoResponse()
-
-    def _delete(self, *keys):
-        ans = 0
-        done = set()
-        for key in keys:
-            if key and key.key not in done:
-                key.value = None
-                done.add(key.key)
-                ans += 1
-        return ans
-
-    def _expireat(self, key, timestamp, *args):
-        nx = False
-        xx = False
-        gt = False
-        lt = False
-        for arg in args:
-            if casematch(b'nx', arg):
-                nx = True
-            elif casematch(b'xx', arg):
-                xx = True
-            elif casematch(b'gt', arg):
-                gt = True
-            elif casematch(b'lt', arg):
-                lt = True
-            else:
-                raise SimpleError(msgs.EXPIRE_UNSUPPORTED_OPTION.format(arg))
-        if self.version < 7 and (nx or xx or gt or lt):
-            raise SimpleError(msgs.WRONG_ARGS_MSG.format('expire'))
-        counter = (nx, gt, lt).count(True)
-        if (counter > 1) or (nx and xx):
-            raise SimpleError(msgs.NX_XX_GT_LT_ERROR_MSG)
-        if (not key
-                or (xx and key.expireat is None)
-                or (nx and key.expireat is not None)
-                or (gt and key.expireat is not None and timestamp < key.expireat)
-                or (lt and key.expireat is not None and timestamp > key.expireat)):
-            return 0
-        key.expireat = timestamp
-        return 1
-
-    def _zpop(self, key, count, reverse):
-        zset = key.value
-        members = list(zset)
-        if reverse:
-            members.reverse()
-        members = members[:count]
-        res = [(bytes(member), self._encodefloat(zset.get(member), True)) for member in members]
-        res = list(itertools.chain.from_iterable(res))
-        for item in members:
-            zset.discard(item)
-        return res
-
-    def _bzpop(self, keys, reverse, first_pass):
-        for key in keys:
-            item = CommandItem(key, self._db, item=self._db.get(key), default=[])
-            temp_res = self._zpop(item, 1, reverse)
-            if temp_res:
-                return [key, temp_res[0], temp_res[1]]
-        return None
+    def _encodeint(self, value):
+        if self.version >= 7:
+            value = 0 + value
+        return Int.encode(value)
